import { useState , useEffect} from 'react';
import { csv, arc, scaleBand, scaleLinear, max, tick } from 'd3';
import { message } from './message';

const csvUrl = 'https://gist.githubusercontent.com/curran/0ac4077c7fc6390f5dd33bf5c06cb5ff/raw/605c54080c7a93a417a3cea93fd52e7550e76500/UN_Population_2019.csv';


const width = 960;
const height = 500;

const margin = {top:20, right:20, bottom:20, left:200}

export const App = () =>{
  const [data, setData] = useState(null);  
  
  useEffect(()=>{
    const row = (d) => {
      d.Population = +d['2020'];
    	return d
    }
    
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 10));
    });
  }, [])
  
  if(!data) return <pre>Data is loading...</pre> 
  
	const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
	const yScale = scaleBand()
  								.domain(data.map(d => d.Country))
  								.range([0, innerHeight]);
  
	const xScale = scaleLinear()
  								.domain([0, max(data, (d) => d.Population)])
  								.range([0, innerWidth]);
  
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left}, ${margin.top})`}>
        {yScale.domain().map(tickValue => (
          <text 
              text-anchor="end" 
              x={-3} dy=".32em" 
              y={ yScale(tickValue) + yScale.bandwidth() / 2 }
          >
          	{tickValue}
          </text>
        ))}
        
				{xScale.ticks().map(tickValue => (
          <g transform={`translate(${xScale(tickValue)}, 0)`}>
            <text y={innerHeight + 3} dy=".71em" text-anchor="middle">{tickValue}</text>          
            <line
              y2={innerHeight}
              stroke="black"
            />
          </g>
        ))}z
        {data.map((d) => {
      	  return <rect 
                   x={0} 
                   y={yScale(d.Country)} 
                   width={xScale(d.Population)} 
                   height={yScale.bandwidth()}
                />
        })
      }
      </g>
    </svg>
  )
}
